import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React, { useState, useContext } from 'react';
import AppContext from './AppContext';
import AmpAccordion from './amp/AmpAccordion';
var AccordionContext = React.createContext();
export var withAccordionContext = function withAccordionContext(Component) {
  return function (props) {
    return React.createElement(AccordionContext.Consumer, null, function (ctx) {
      return React.createElement(Component, _extends({}, props, ctx));
    });
  };
};
/**
 * Accordion which only allows one child ExpandableSection to be open at a time
 *
 * ```js
 *  <Accordion>
 *    <ExpandableSection title="First">
 *      <div>The first section</div>
 *    </ExpandableSection>
 *    <ExpandableSection title="Second">
 *      <div>The second section</div>
 *    </ExpandableSection>
 *    <ExpandableSection title="Third">
 *      <div>The third section</div>
 *    </ExpandableSection>
 *  </Accordion>
 * ```
 */

export default function Accordion(_ref) {
  var children = _ref.children,
      otherProps = _objectWithoutProperties(_ref, ["children"]);

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      expandedSectionId = _useState2[0],
      setExpandedSectionId = _useState2[1];

  var _useContext = useContext(AppContext),
      amp = _useContext.app.amp;

  return React.createElement(AccordionContext.Provider, {
    value: {
      expandedSectionId: expandedSectionId,
      setExpandedSectionId: setExpandedSectionId
    }
  }, amp ? React.createElement(AmpAccordion, otherProps, children) : children);
}
//# sourceMappingURL=Accordion.js.map