import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React from 'react';
import withStyles from '@material-ui/core/styles/withStyles';
import Button from '@material-ui/core/Button';
import PropTypes from 'prop-types';
import Typography from '@material-ui/core/Typography';
export var styles = function styles(theme) {
  return {
    raised: {
      boxShadow: 'none',
      backgroundColor: '#F4F2F1'
    },
    label: {
      justifyContent: 'space-between',
      alignItems: 'baseline',
      textTransform: 'none'
    },
    caption: {
      textTransform: 'none',
      fontWeight: 'bold'
    },
    value: {
      color: theme.palette.text.primary,
      whiteSpace: 'nowrap',
      textOverflow: 'ellipses',
      marginLeft: '10px'
    }
  };
};
/**
 * This button class displays a label and value
 */

function ActionButton(_ref) {
  var label = _ref.label,
      value = _ref.value,
      children = _ref.children,
      classes = _ref.classes,
      props = _objectWithoutProperties(_ref, ["label", "value", "children", "classes"]);

  var captionClass = classes.caption,
      valueClass = classes.value,
      otherClasses = _objectWithoutProperties(classes, ["caption", "value"]);

  return React.createElement(Button, _extends({
    variant: "contained",
    classes: otherClasses
  }, props), React.createElement(Typography, {
    variant: "button",
    className: captionClass
  }, label), React.createElement(Typography, {
    variant: "caption",
    className: valueClass
  }, value));
}

ActionButton.propTypes = {
  /**
   * The label to display on the left side of the button
   */
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /**
   * The value to display on the right side of the button
   */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.element])
};
export default withStyles(styles, {
  name: 'RSFActionButton'
})(ActionButton);
//# sourceMappingURL=ActionButton.js.map