import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _dec, _class, _class2, _temp;

/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */
import { Component } from 'react';
import PropTypes from 'prop-types';
import { inject } from 'mobx-react';
/**
 * An internal component that catches errors durring rendering, sets the
 * error, stack, and page properties of the app state accordingly, and calls
 * the registered error reporter if one is configured.
 */

var ErrorBoundary = (_dec = inject('app', 'history'), _dec(_class = (_temp = _class2 =
/*#__PURE__*/
function (_Component) {
  _inherits(ErrorBoundary, _Component);

  function ErrorBoundary() {
    _classCallCheck(this, ErrorBoundary);

    return _possibleConstructorReturn(this, _getPrototypeOf(ErrorBoundary).apply(this, arguments));
  }

  _createClass(ErrorBoundary, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props = this.props,
          app = _this$props.app,
          history = _this$props.history,
          onError = _this$props.onError;
      this.windowErrorEvent = window.addEventListener('error', function (event) {
        onError({
          error: event.error,
          history: history,
          app: app
        });
      });
      this.windowUnhandledRejectionEvent = window.addEventListener('unhandledrejection', function (event) {
        onError({
          error: event.reason,
          history: history,
          app: app
        });
      });
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.removeEventListener('error', this.windowErrorEvent);
      window.removeEventListener('unhandledrejection', this.windowUnhandledRejectionEvent);
    }
    /**
     * When an error is caught, call the error reporter and update the app state
     * @param {Error} error
     * @param {Object} info
     */

  }, {
    key: "componentDidCatch",
    value: function componentDidCatch(error, info) {
      var _this$props2 = this.props,
          app = _this$props2.app,
          history = _this$props2.history,
          onError = _this$props2.onError; // report the error

      onError({
        error: error,
        app: app,
        history: history
      }); // update the app state to cause the error view to be displayed

      app.applyState({
        page: 'Error',
        error: error.message,
        stack: info.componentStack
      }); // this is needed to recover from the error and render the error view since we're
      // not actually observing anything on the state tree in this component.

      this.forceUpdate();
    }
  }, {
    key: "render",
    value: function render() {
      return this.props.children;
    }
  }]);

  return ErrorBoundary;
}(Component), _defineProperty(_class2, "propTypes", {
  /**
   * A function to call whenever an error occurs.  The function is passed an
   * object with `error` (the error message) and `stack` (the stack trace as a string).
   */
  onError: PropTypes.func
}), _defineProperty(_class2, "defaultProps", {
  onError: Function.prototype
}), _temp)) || _class);
export { ErrorBoundary as default };
//# sourceMappingURL=ErrorBoundary.js.map