import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectSpread from "@babel/runtime/helpers/objectSpread";

var _dec, _dec2, _dec3, _class, _class2, _temp;

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React, { Component, Fragment } from 'react';
import { observer, inject } from 'mobx-react';
import PropTypes from 'prop-types';
import Drawer from '@material-ui/core/Drawer';
import withStyles from '@material-ui/core/styles/withStyles';
import classnames from 'classnames';
import AmpMenu from './amp/AmpMenu';
import withTheme from '@material-ui/core/styles/withTheme';
import Body from './menu/Body';
import SEOLinks from './menu/SEOLinks';
import MenuContext from './menu/MenuContext';
import AmpSimpleMenu from './amp/AmpSimpleMenu';
export { MenuModel, MenuItemModel } from './model/MenuModel';
export var styles = function styles(theme) {
  return {
    drawer: {
      zIndex: theme.zIndex.modal + 20,
      display: 'flex',
      flexDirection: 'column',
      borderTop: "".concat(theme.headerHeight, "px solid transparent"),
      'body.moov-safari &': {
        // Turning off momentum scrolling on iOS here to fix frozen body issue
        // Source: https://moovweb.atlassian.net/browse/PRPL-342
        '-webkit-overflow-scrolling': 'auto'
      }
    },
    list: {
      flex: 'none',
      overflowY: 'auto',
      overflowX: 'hidden',
      maxHeight: '100%',
      padding: 0
    },
    ampList: {
      flex: 'none',
      overflowX: 'hidden',
      padding: 0
    },
    ampBody: {
      overflowY: 'auto',
      height: '100%',
      left: 0,
      top: 0,
      position: 'absolute',
      width: '100%',
      flex: '1 1 0%',
      transition: 'transform ease-out .2s'
    },
    hiddenLeft: {
      transform: "translateX(-".concat(theme.drawerWidth, "px)")
    },
    hiddenRight: {
      transform: "translateX(".concat(theme.drawerWidth, "px)")
    },
    inFocus: {
      transform: 'translateX(0px)'
    },
    listPadding: {
      padding: 0
    },
    header: {
      position: 'absolute',
      left: '10px',
      top: '12px'
    },
    icon: {
      marginRight: '0',
      width: 24
    },
    headerText: {
      textAlign: 'center',
      fontWeight: '600',
      textTransform: 'uppercase',
      fontSize: theme.typography.body1.fontSize
    },
    bodyWrap: {
      display: 'flex',
      flexDirection: 'row',
      transition: 'all ease-out .2s',
      maxHeight: '100%'
    },
    hidden: {
      display: 'none'
    },
    visible: {
      display: 'block'
    },
    listItem: {
      textTransform: 'uppercase',
      lineHeight: 'initial',
      fontSize: theme.typography.body1.fontSize
    },
    link: {
      textDecoration: 'none',
      color: 'inherit'
    },
    listItemImage: {
      width: '40px',
      height: '40px',
      marginRight: 0
    },
    listItemIcon: {
      marginRight: 0
    },
    expander: {
      backgroundColor: "".concat(theme.palette.primary.paper, " !important")
    },
    leaf: _objectSpread({
      textTransform: 'none'
    }, theme.typography.body1),
    expanded: {
      backgroundColor: "".concat(theme.palette.secondary.main, " !important"),
      color: theme.palette.secondary.contrastText,
      '& svg': {
        color: theme.palette.secondary.contrastText
      }
    },
    drawerFixed: {
      top: 0,
      height: '100vh',
      borderTop: 'none'
    },
    modal: {},
    loadingIcon: {
      display: 'block'
    }
  };
};
/**
 * The main app menu that slides in from the left when the AppHeader's menu button is clicked.
 * Children are rendered above the list of menu items.
 *
 * In addition to the CSS classes that can be overridden of menu subcomponents, you can also
 * assign specific classes to individual menu items by specifying a value for the `className`
 * field on any instance of `MenuItemModel`.
 */

var Menu = (_dec = withTheme(), _dec2 = withStyles(styles, {
  name: 'RSFMenu'
}), _dec3 = inject('app'), _dec(_class = _dec2(_class = _dec3(_class = observer(_class = (_temp = _class2 =
/*#__PURE__*/
function (_Component) {
  _inherits(Menu, _Component);

  function Menu(_ref) {
    var _this;

    var classes = _ref.classes;

    _classCallCheck(this, Menu);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Menu).call(this));
    _this.menuContext = {
      classes: classes
    };
    return _this;
  }

  _createClass(Menu, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          app = _this$props.app,
          classes = _this$props.classes,
          className = _this$props.className,
          align = _this$props.align,
          drawerWidth = _this$props.drawerWidth,
          persistent = _this$props.persistent,
          simple = _this$props.simple,
          others = _objectWithoutProperties(_this$props, ["app", "classes", "className", "align", "drawerWidth", "persistent", "simple"]);

      var amp = app.amp,
          menu = app.menu;

      if (!menu) {
        return null;
      } else if (amp) {
        if (simple) {
          return React.createElement(AmpSimpleMenu, this.props);
        } else {
          return React.createElement(MenuContext.Provider, {
            value: this.menuContext
          }, React.createElement(AmpMenu, this.props));
        }
      } else {
        return React.createElement(Fragment, null, React.createElement(Drawer, {
          variant: persistent ? 'persistent' : 'temporary',
          open: menu.open || persistent,
          onClose: menu.close,
          anchor: align,
          ModalProps: {
            keepMounted: true
          },
          PaperProps: {
            style: {
              width: "".concat(drawerWidth, "px")
            }
          },
          classes: {
            root: className,
            paper: classnames(classes.drawer, _defineProperty({}, classes.drawerFixed, persistent)),
            modal: classes.modal
          }
        }, React.createElement(MenuContext.Provider, {
          value: this.menuContext
        }, React.createElement(Body, _extends({
          drawerWidth: drawerWidth,
          simple: simple
        }, others)))), React.createElement(SEOLinks, null));
      }
    }
  }]);

  return Menu;
}(Component), _defineProperty(_class2, "propTypes", {
  menu: PropTypes.object,

  /**
   * The width of the drawer in pixels
   */
  drawerWidth: PropTypes.number,

  /**
   * An element to display at the top of the root of the menu
   */
  rootHeader: PropTypes.element,

  /**
   * An element to display at the bottom of the root of the menu
   */
  rootFooter: PropTypes.element,

  /**
   * A function to render a custom header in leaf lists.  It is passed an object
   * with:
   *
   * - list: The menu model being rendered
   * - goBack: A function to call to go back to the previous list
   *
   * The function should return a React element or fragment.
   */
  renderLeafHeader: PropTypes.func,

  /**
   * A function to render a custom footer in leaf lists.  It is passed an object
   * with:
   *
   * - list: The menu model being rendered
   *
   * The function should return a React element or fragment.
   */
  renderLeafFooter: PropTypes.func,

  /**
   * Set to true to use expandable menu items below depth 1
   */
  useExpanders: PropTypes.bool,

  /**
   * Set to true to expand first item for not root items
   */
  expandFirstItem: PropTypes.bool,

  /**
   * Set to true to display the menu
   */
  open: PropTypes.bool,

  /**
   * Set to true to dock the menu so that it's always open and not modal
   */
  persistent: PropTypes.bool,

  /**
   * CSS classes for this component
   */
  classes: PropTypes.objectOf(PropTypes.string),

  /**
   * Called when the menu is closed
   */
  onClose: PropTypes.func,

  /**
   * Set to true to render a simple set of expanders rather than a multi-level drill down.
   * Defaults to false.
   */
  simple: PropTypes.bool,

  /**
   * The icon to use for collapsed groups
   */
  ExpandIcon: PropTypes.func,

  /**
   * The icon to use for expanded groups
   */
  CollapseIcon: PropTypes.func,

  /**
   * Sets the side of the screen from which the menu appears.
   */
  align: PropTypes.oneOf(['left', 'right']),

  /**
   * Overrides the default rendering of a menu item.  It is passed the following arguments:
   *
   * - item - the MenuItemModel instance.
   *
   * Return undefined to render the default contents
   *
   * Example:
   *
   * ```js
   *  itemRenderer={item => {
   *    return item.text === 'My Special Item ? <MySpecialItem/> : null
   *  }}
   * ```
   */
  itemRenderer: PropTypes.func,

  /**
   * Overrides the content of a menu item.  It is passed the following arguments:
   *
   * - item - the MenuItemModel instance.
   * - leaf - `true` when the item is a leaf node, otherwise `false`
   *
   * Return null to render the default contents
   *
   * Example:
   *
   * ```js
   *  itemContentRenderer={(item, leaf) => {
   *    return leaf ? <ListItemText primary={item.text}/> : null
   *  }}
   * ```
   */
  itemContentRenderer: PropTypes.func,

  /**
   * Set to `true` to show the item corresponding to the current URL as selected.
   */
  trackSelected: PropTypes.bool
}), _defineProperty(_class2, "defaultProps", {
  drawerWidth: 330,
  simple: false,
  expandFirstItem: false,
  align: 'left',
  trackSelected: false
}), _temp)) || _class) || _class) || _class) || _class);
export { Menu as default };
//# sourceMappingURL=Menu.js.map