import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import "core-js/modules/web.dom.iterable";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React, { Component } from 'react';
import GridListTile from '@material-ui/core/GridListTile';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import withStyles from '@material-ui/core/styles/withStyles';
/**
 * A responsive grid of tiles that changes the number of columns based on the viewport size.
 * This component commonly used in product listings and search results.
 */

var ResponsiveTiles =
/*#__PURE__*/
function (_Component) {
  _inherits(ResponsiveTiles, _Component);

  function ResponsiveTiles(props) {
    var _this;

    _classCallCheck(this, ResponsiveTiles);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ResponsiveTiles).call(this, props));
    _this.Tiles = createInner(props);
    return _this;
  }

  _createClass(ResponsiveTiles, [{
    key: "render",
    value: function render() {
      var Tiles = this.Tiles;

      var _this$props = this.props,
          cols = _this$props.cols,
          spacing = _this$props.spacing,
          others = _objectWithoutProperties(_this$props, ["cols", "spacing"]);

      return React.createElement(Tiles, others);
    }
  }]);

  return ResponsiveTiles;
}(Component);

_defineProperty(ResponsiveTiles, "propTypes", {
  /**
   * A map of viewport widths to number of columns.  For example:
   * ```
   *  cols={{
   *    xs: 2,
   *    sm: 3,
   *    md: 4,
   *    lg: 5,
   *    xl: 5
   *  }}
   * ```
   *
   * The amounts shown in the example above are the defaults.
   */
  cols: PropTypes.object,

  /**
   * The spacing between the tiles in pixels. Defaults to 15
   */
  spacing: PropTypes.number
});

_defineProperty(ResponsiveTiles, "defaultProps", {
  cols: {
    xs: 2,
    sm: 3,
    md: 4,
    lg: 5,
    xl: 5
  },
  spacing: 15
});

export { ResponsiveTiles as default };

function createInner(_ref) {
  var spacing = _ref.spacing,
      cols = _ref.cols;

  var styles = function styles(theme) {
    var breakpoints = {}; // Breakpoints MUST be set in order from smallest to largest

    Object.keys(cols).map(function (width) {
      return {
        key: width,
        value: cols[width],
        width: "".concat(100 / cols[width], "%")
      };
    }).sort(function (a, b) {
      return a.value - b.value;
    }).forEach(function (_ref2) {
      var key = _ref2.key,
          width = _ref2.width;
      breakpoints[theme.breakpoints.up(key)] = {
        width: width
      };
    });
    return {
      root: {
        display: 'flex',
        flexWrap: 'wrap',
        overflowY: 'auto',
        listStyle: 'none',
        padding: 0,
        margin: "-".concat(spacing / 2, "px"),
        WebkitOverflowScrolling: 'touch' // Add iOS momentum scrolling.

      },
      tile: _objectSpread({}, breakpoints, {
        padding: "".concat(spacing / 2, "px"),
        height: 'auto'
      })
    };
  };

  var ResponsiveTilesInner =
  /*#__PURE__*/
  function (_Component2) {
    _inherits(ResponsiveTilesInner, _Component2);

    function ResponsiveTilesInner() {
      _classCallCheck(this, ResponsiveTilesInner);

      return _possibleConstructorReturn(this, _getPrototypeOf(ResponsiveTilesInner).apply(this, arguments));
    }

    _createClass(ResponsiveTilesInner, [{
      key: "render",
      value: function render() {
        var _this$props2 = this.props,
            className = _this$props2.className,
            classes = _this$props2.classes,
            children = _this$props2.children,
            other = _objectWithoutProperties(_this$props2, ["className", "classes", "children"]);

        return React.createElement("ul", _extends({
          className: classnames(className, classes.root)
        }, other), React.Children.map(children, function (child, i) {
          if (!React.isValidElement(child)) {
            return null;
          }

          return React.createElement(GridListTile, {
            key: i,
            classes: {
              root: classes.tile
            }
          }, child);
        }));
      }
    }]);

    return ResponsiveTilesInner;
  }(Component);

  return withStyles(styles, {
    name: 'RSFResponsiveTiles'
  })(ResponsiveTilesInner);
}
//# sourceMappingURL=ResponsiveTiles.js.map