import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _dec, _class, _class2, _temp, _dec2, _class3, _class4, _temp2;

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React, { Component, Fragment } from 'react';
import withStyles from '@material-ui/core/styles/withStyles';
import classnames from 'classnames';
import ResponsiveTiles from './ResponsiveTiles';
import PropTypes from 'prop-types';
import withStyleProps from './withStyleProps';
import { observer, inject } from 'mobx-react';
import Image from './Image';
export var styles = function styles(theme) {
  return {
    row: {
      display: 'flex',
      flexDirection: 'row',
      alignItems: 'stretch'
    },
    blankRow: {
      height: "".concat(theme.margins.row, "px")
    },
    space: {
      backgroundColor: theme.palette.background.default,
      width: theme.margins.container + 'px'
    },
    '@keyframes shimmer': {
      from: {
        backgroundPosition: '0 0'
      },
      to: {
        backgroundPosition: '100vw 0'
      }
    },
    shimmer: {
      backgroundColor: theme.palette.background.shade,
      animationDuration: '1s',
      animationFillMode: 'forwards',
      animationIterationCount: 'infinite',
      animationName: 'shimmer',
      animationTimingFunction: 'linear',
      background: "linear-gradient(to right, #eee 0%, #e6e6e6 20%, #eee 40%)"
    },
    fullscreen: {
      position: 'absolute',
      left: 0,
      right: 0,
      bottom: 0,
      top: theme.headerHeight
    },
    filledContent: {
      backgroundColor: theme.palette.background.default,
      display: 'flex',
      alignItems: 'center'
    }
  };
};
/**
 * The root component for a skeleton view
 */

export var Skeleton = withStyles(styles)(function (_ref) {
  var _classnames;

  var classes = _ref.classes,
      children = _ref.children,
      _ref$fullscreen = _ref.fullscreen,
      fullscreen = _ref$fullscreen === void 0 ? false : _ref$fullscreen;
  return React.createElement("div", {
    className: classnames((_classnames = {}, _defineProperty(_classnames, classes.shimmer, true), _defineProperty(_classnames, classes.fullscreen, fullscreen), _classnames))
  }, children);
});
/**
 * A row of space and content
 */

export var Row = withStyles(styles)(function (_ref2) {
  var wrap = _ref2.wrap,
      className = _ref2.className,
      classes = _ref2.classes,
      children = _ref2.children,
      style = _objectWithoutProperties(_ref2, ["wrap", "className", "classes", "children"]);

  return React.createElement("div", {
    className: classnames(classes.row, className),
    style: _objectSpread({
      flexWrap: wrap && 'wrap'
    }, style)
  }, children);
});
/**
 * White space between content
 */

export var Space = withStyles(styles)(function (_ref3) {
  var classes = _ref3.classes,
      style = _objectWithoutProperties(_ref3, ["classes"]);

  return React.createElement("div", {
    "data-rel": "space",
    className: classes.space,
    style: style
  });
});
/**
 * A placeholder for content with a gray background that shimmers
 */

export var Content = withStyles(styles)(function (_ref4) {
  var children = _ref4.children,
      className = _ref4.className,
      classes = _ref4.classes,
      style = _objectWithoutProperties(_ref4, ["children", "className", "classes"]);

  if (children) {
    return React.createElement("div", {
      className: classnames(className, classes.filledContent),
      style: _objectSpread({}, style)
    }, children);
  } else {
    return React.createElement("div", {
      className: className,
      style: _objectSpread({}, style)
    });
  }
});
/**
 * A blank row.  You provide the height
 */

export var BlankRow = withStyles(styles)(function (_ref5) {
  var classes = _ref5.classes,
      others = _objectWithoutProperties(_ref5, ["classes"]);

  return React.createElement(Row, _extends({
    className: classes.blankRow
  }, others), React.createElement(Space, {
    flex: 1
  }));
});
/**
 * When using ResposiveTiles in your view, use this component to replace
 * it in the load mask.
 */

export var Tiles = (_dec = withStyleProps(function (_ref6) {
  var theme = _ref6.theme,
      spacing = _ref6.spacing;
  return {
    root: {
      borderStyle: 'solid',
      borderColor: theme.palette.background.default,
      margin: "0 -".concat(spacing, "px !important")
    },
    tile: {
      borderStyle: 'solid',
      borderColor: theme.palette.background.default,
      borderWidth: "0 ".concat(spacing / 2, "px")
    }
  };
}, {
  name: 'RSFSkeletonTiles'
}), _dec(_class = (_temp = _class2 =
/*#__PURE__*/
function (_Component) {
  _inherits(Tiles, _Component);

  function Tiles() {
    _classCallCheck(this, Tiles);

    return _possibleConstructorReturn(this, _getPrototypeOf(Tiles).apply(this, arguments));
  }

  _createClass(Tiles, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          spacing = _this$props.spacing,
          classes = _this$props.classes,
          className = _this$props.className,
          children = _this$props.children,
          others = _objectWithoutProperties(_this$props, ["spacing", "classes", "className", "children"]);

      return React.createElement(ResponsiveTiles, _extends({
        spacing: 0,
        className: classnames(classes.root, className)
      }, others), React.Children.map(children, function (child, i) {
        return React.createElement("div", {
          className: classes.tile,
          key: i
        }, child);
      }));
    }
  }]);

  return Tiles;
}(Component), _defineProperty(_class2, "propTypes", {
  /**
   * Should be the same as the spacing set on the ResponsiveTiles element
   * that you're replacing.
   */
  spacing: PropTypes.number
}), _temp)) || _class);
Tiles.defaultProps = {
  spacing: 15
};
export var ImageSwitcher = (_dec2 = withStyles(function (theme) {
  return {
    root: {
      display: 'flex',
      flexDirection: 'column'
    },
    image: {
      width: '100%',
      flex: 1
    }
  };
}), _dec2(_class3 = observer(_class3 = (_temp2 = _class4 =
/*#__PURE__*/
function (_Component2) {
  _inherits(ImageSwitcher, _Component2);

  function ImageSwitcher() {
    _classCallCheck(this, ImageSwitcher);

    return _possibleConstructorReturn(this, _getPrototypeOf(ImageSwitcher).apply(this, arguments));
  }

  _createClass(ImageSwitcher, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          classes = _this$props2.classes,
          thumbnails = _this$props2.thumbnails,
          product = _this$props2.product,
          loadingThumbnailProps = _this$props2.loadingThumbnailProps;
      return React.createElement("div", {
        className: classes.root
      }, product && product.thumbnail ? React.createElement(Row, null, React.createElement(Content, {
        flex: "1"
      }, React.createElement(Image, _extends({
        src: product.thumbnail,
        className: classes.image
      }, loadingThumbnailProps, {
        fill: true
      })))) : React.createElement(Row, {
        className: classes.image
      }), thumbnails ? React.createElement(Fragment, null, React.createElement(BlankRow, null), React.createElement(Row, {
        height: "58px"
      }, React.createElement(Space, null), React.createElement(Content, {
        flex: "1"
      }), React.createElement(Space, null))) : null);
    }
  }]);

  return ImageSwitcher;
}(Component), _defineProperty(_class4, "propTypes", {
  product: PropTypes.object,
  thumbnails: PropTypes.bool,
  loadingThumbnailProps: PropTypes.object
}), _defineProperty(_class4, "defaultProps", {
  thumbnails: true,
  loadingThumbnailProps: {}
}), _temp2)) || _class3) || _class3);
//# sourceMappingURL=Skeleton.js.map