import "core-js/modules/web.dom.iterable";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

var _dec, _dec2, _class, _class2, _temp;

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React, { Component } from 'react';
import withStyles from '@material-ui/core/styles/withStyles';
import { Helmet } from 'react-helmet';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import { inject } from 'mobx-react';
import classnames from 'classnames';
import PropTypes from 'prop-types';
export var styles = function styles(theme) {
  return {
    root: {},
    panel: {
      margin: "".concat(theme.margins.container, "px 0")
    },
    hidden: {
      display: 'none'
    },
    ampSelector: {
      '& [option][selected]': {
        outline: 'none',
        cursor: 'inherit'
      }
    },
    ampPanel: {
      display: 'none',
      '&[selected]': {
        display: 'block'
      }
    },
    ampTab: {
      opacity: 1,
      '& .label': {
        borderBottom: "2px solid transparent",
        opacity: 0.7,
        padding: '15px 12px 14px 12px'
      },
      '& .selected': {
        borderBottom: "2px solid ".concat(theme.palette.secondary.main),
        opacity: 1
      }
    },
    ampTabLabelContainer: {
      padding: 0
    },
    ampTabIndicator: {
      display: 'none'
    }
  };
};
/**
 * A simple tab panel that is AMP-compatible.  Tab names are pull from the label prop of the child elements.
 * Any type of element can be a child.
 *
 * Example:
 *
 * ```js
 *  <TabPanel>
 *    <div label="Description">
 *      Description here
 *    </div>
 *    <CmsSlot label="Instructions">
 *      { instructionsFromCms }
 *    </CmsSlot>
 *  </TabPanel>
 * ```
 */

var TabPanel = (_dec = withStyles(styles, {
  name: 'RSFTabPanel'
}), _dec2 = inject('app', 'ampStateId'), _dec(_class = _dec2(_class = (_temp = _class2 =
/*#__PURE__*/
function (_Component) {
  _inherits(TabPanel, _Component);

  function TabPanel(props) {
    var _this;

    _classCallCheck(this, TabPanel);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(TabPanel).call(this, props));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "onChange", function (event, selected) {
      var onChange = _this.props.onChange;

      _this.setState({
        selected: selected
      });

      if (onChange) {
        onChange(selected);
      }
    });

    _this.state = {
      selected: props.selected
    };
    return _this;
  }

  _createClass(TabPanel, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      if (typeof nextProps.selected === 'number') {
        this.setState({
          selected: nextProps.selected
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var selected = this.state.selected;
      var _this$props = this.props,
          children = _this$props.children,
          classes = _this$props.classes,
          app = _this$props.app,
          ampStateId = _this$props.ampStateId,
          ampStateProperty = _this$props.ampStateProperty,
          scrollable = _this$props.scrollable;
      var amp = app.amp;
      var panels = [];
      var tabs = [];
      React.Children.forEach(children, function (child, i) {
        var _classnames3;

        var label = child.props.label;

        if (amp) {
          label = React.createElement("div", {
            className: classnames('label', {
              selected: selected === i
            }),
            "amp-bind": "class=>".concat(ampStateId, ".").concat(ampStateProperty, " == \"tab").concat(i, "\" || (").concat(i, " == 0 && !").concat(ampStateId, ".").concat(ampStateProperty, ") ? 'label selected' : 'label'")
          }, label);
        }

        tabs.push(React.createElement(Tab, {
          key: i,
          label: label,
          on: "tap:AMP.setState({ ".concat(ampStateId, ": { ").concat(ampStateProperty, ": 'tab").concat(i, "' }})"),
          classes: {
            root: classnames(_defineProperty({}, classes.ampTab, amp)),
            labelContainer: classnames(_defineProperty({}, classes.ampTabLabelContainer, amp))
          }
        }));
        panels.push(React.createElement("div", {
          key: i,
          role: "tabpanel",
          option: "tab".concat(i),
          selected: i === selected,
          className: classnames(classes.panel, (_classnames3 = {}, _defineProperty(_classnames3, classes.hidden, !amp && i !== selected), _defineProperty(_classnames3, classes.ampPanel, amp), _classnames3))
        }, React.cloneElement(child, {
          label: null
        })));
      });

      if (amp) {
        panels = React.createElement("amp-selector", {
          role: "tablist",
          "amp-bind": "selected=>".concat(ampStateId, ".").concat(ampStateProperty),
          class: classes.ampSelector
        }, panels);
      }

      return React.createElement("div", {
        className: classes.root
      }, amp && React.createElement(Helmet, null, React.createElement("script", {
        async: true,
        "custom-element": "amp-selector",
        src: "https://cdn.ampproject.org/v0/amp-selector-0.1.js"
      }), React.createElement("script", {
        async: true,
        "custom-element": "amp-bind",
        src: "https://cdn.ampproject.org/v0/amp-bind-0.1.js"
      })), React.createElement(Tabs, {
        variant: scrollable ? 'scrollable' : null,
        value: selected,
        onChange: this.onChange,
        classes: {
          indicator: classnames(_defineProperty({}, classes.ampTabIndicator, amp))
        }
      }, tabs), panels);
    }
  }]);

  return TabPanel;
}(Component), _defineProperty(_class2, "propTypes", {
  /**
   * Set to false to prevent the tabs from scrolling
   */
  scrollable: PropTypes.bool,

  /**
   * Selected tab index
   */
  selected: PropTypes.number,

  /**
   * On change callback
   */
  onChange: PropTypes.func
}), _defineProperty(_class2, "defaultProps", {
  ampStateId: 'moovAmpState',
  ampStateProperty: 'selectedTab',
  variant: 'scrollable',
  selected: 0
}), _temp)) || _class) || _class);
export { TabPanel as default };
//# sourceMappingURL=TabPanel.js.map