import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import _objectSpread from "@babel/runtime/helpers/objectSpread";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import { onSnapshot, getSnapshot, applySnapshot } from 'mobx-state-tree';
import Storage from 'store2';
/**
 *  Example:
 *
 *  ```js
 *  import { persist } from 'path/to/persist'
 *
 *  export const ModelName = types
 *   .model('ModelName', {
 *     keyOne: 'includeMe',
 *     keyTwo: 'excludeMe'
 *   })
 *   .actions(self => ({
 *     afterCreate() {
 *       persist('storageName', self, {
 *         keyOne: true,
 *       })
 *     }
 *   }))
 * ```
 *
 * @param {String} name The name of the item in storage
 * @param {Model} store The mobx state tree model to store
 * @param {Object} schema OPTIONAL object of model keys, used to limit what gets stored - all keys stored by default
 */

export default function persist(name, store) {
  var schema = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  onSnapshot(store, function (_snapshot) {
    var snapshot = _objectSpread({}, _snapshot); // use only keys found in schema
    // if schema is empty store everything


    if (Object.keys(schema).length) {
      Object.keys(snapshot).forEach(function (key) {
        if (!schema[key]) {
          delete snapshot[key];
        }
      });
    }

    Storage.set(name, snapshot);
  });
  var snapshot = Storage.get(name);

  if (snapshot) {
    applySnapshot(store, snapshot);
  }
}
//# sourceMappingURL=persist.js.map