/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */
var impl;
export function setImplementation(i) {
  impl = i;
}
/**
 * Usage:
 *
 * import requestContext from 'react-storefront/requestContext'
 *
 * export default function(params, req, res) {
 *   if (condition) {
 *      requestContext.set('foo', params.foo)
 *   }
 *   res.set('bar', requestContext.get('bar'))
 *   res.json({})
 * }
 */

export default {
  get: function get() {
    var _impl;

    if (!impl) {
      console.warn('requestContext implementation not provided, returning undefined');
      return undefined;
    }

    return (_impl = impl).get.apply(_impl, arguments);
  },
  set: function set() {
    var _impl2;

    if (!impl) {
      console.warn('requestContext implementation not provided, skipping.');
      return;
    }

    (_impl2 = impl).set.apply(_impl2, arguments);
  }
};
//# sourceMappingURL=requestContext.js.map