import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.promise";

/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */

/**
 * @param {*} batchSize The number of promises to run concurrently
 * @param {*} thenArr
 * @param {*} fn
 */
export default function (batchSize, thenArr, fn) {
  return Promise.resolve(thenArr).then(function (arr) {
    return arr.map(function (_, i) {
      return i % batchSize ? [] : arr.slice(i, i + batchSize);
    }).map(function (group) {
      return function (res) {
        return Promise.all(group.map(fn)).then(function (r) {
          return res.concat(r);
        });
      };
    }).reduce(function (chain, work) {
      return chain.then(work);
    }, Promise.resolve([]));
  });
}
//# sourceMappingURL=batchPromises.js.map