import _extends from "@babel/runtime/helpers/extends";
import "core-js/modules/es6.object.assign";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React from 'react';
import ReactDOM from 'react-dom';
import { Provider } from 'mobx-react';
import JssProvider from 'react-jss/lib/JssProvider';
import { create } from 'jss';
import { jssPreset } from '@material-ui/core/styles';
import jssNested from 'jss-nested';
import { MuiThemeProvider } from '@material-ui/core/styles';
import createGenerateClassName from './createGenerateClassName';
/**
 * Removes the style tag rendered on the server so that components are styled correctly
 * after hydration.
 * @private
 */

function removeSSRStyles() {
  var jssStyles = document.getElementById('ssr-css');

  if (jssStyles && jssStyles.parentNode) {
    jssStyles.parentNode.removeChild(jssStyles);
  }
}
/**
 * Hydrates React component
 * @private
 * @param  {options} options
 * @param  {React.Component} options.component    Component to be rendered
 * @param  {Model} options.model                  MobX Model
 * @param  {Object} options.theme                 MUI Theme
 * @param  {String} options.target                Selector for rendering target
 * @param  {String} options.providerProps         Props to add the to <Provider/> element
 * @param  {String} options.initialStateProperty  Optional window property name for initial state
 * @return {Object} The app state
 */


export default function hydrate(_ref) {
  var component = _ref.component,
      model = _ref.model,
      theme = _ref.theme,
      target = _ref.target,
      _ref$providerProps = _ref.providerProps,
      providerProps = _ref$providerProps === void 0 ? {} : _ref$providerProps,
      _ref$initialStateProp = _ref.initialStateProperty,
      initialStateProperty = _ref$initialStateProp === void 0 ? 'initialState' : _ref$initialStateProp,
      _ref$cssPrefix = _ref.cssPrefix,
      cssPrefix = _ref$cssPrefix === void 0 ? 'jss' : _ref$cssPrefix;
  var generateClassName = createGenerateClassName();
  var state = model.create(window[initialStateProperty] || {});
  var jss = create(jssPreset(), jssNested());
  window.moov = window.moov || {};
  Object.assign(window.moov, {
    state: state,
    timing: {}
  }, providerProps); // skip jss insertion if we are hydrating SSR cached by the service worker because it has already been mounted

  if (!document.body.hasAttribute('data-jss-inserted')) {
    var styleNode = document.createComment('jss-insertion-point');
    document.head.insertBefore(styleNode, document.head.firstChild);
    jss.options.insertionPoint = 'jss-insertion-point';
    document.body.setAttribute('data-jss-inserted', 'on');
  }

  ReactDOM.hydrate(React.createElement(Provider, _extends({
    app: state
  }, providerProps), React.createElement(JssProvider, {
    classNamePrefix: cssPrefix,
    jss: jss,
    generateClassName: generateClassName
  }, React.createElement(MuiThemeProvider, {
    theme: theme
  }, component))), target, removeSSRStyles);
  return state;
}
//# sourceMappingURL=hydrate.js.map