import _objectSpread from "@babel/runtime/helpers/objectSpread";

/**
 * @license
 * Copyright © 2017-2019 Moov Corporation.  All rights reserved.
 */
import cheerio from 'cheerio';
import qs from 'qs';
/**
 * Transforms image source to come from the Moovweb Image Optimizer
 * @param {String} img         Image source URL
 * @param {Object} options     Transformation options
 * @returns {String}           Optimized image URL
 */

function transformSource(img) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    quality: 75
  };
  var query = qs.stringify(_objectSpread({}, options, {
    img: img
  }));
  return "https://opt.moovweb.net/?".concat(query);
}
/**
 * Transforms images within the given HTML to come from the Moovweb Image Optimizer
 * @param {String} html        Input HTML
 * @param {Object} options     Transformation options
 * @returns {String}           Optimized HTML
 */


export default function optimizeImages(html, options) {
  var $ = cheerio.load(html);
  $('img').each(function () {
    var $img = $(this);
    $img.attr('src', transformSource($img.attr('src'), options));
  });
  return $.html({
    decodeEntities: false
  });
}
//# sourceMappingURL=optimizeImages.js.map