import _objectSpread from "@babel/runtime/helpers/objectSpread";

/**
 * @license
 * Copyright © 2017-2018 Moov Corporation.  All rights reserved.
 */
import React from 'react';
import withStyles from '@material-ui/core/styles/withStyles';
/**
 * Decorator for mapping a component's props to JSS styles
 *
 * Example:
 *
 * ```js
 * import withStyleProps from 'react-storefront'
 * import React, { Component } from 'react'
 *
 * _@_withStyleProps(({ theme, height }) => ({
 *   root: {
 *     height: `${height}px`,
 *   }
 * }))
 * export default class MyComponent extends Component {
 *   render() {
 *     return <div className={this.props.classes.root}>{this.props.children}</div>
 *   }
 * }
 * ```
 *
 * @param {Object} styles
 * @return {React.Component}
 */

export default function withStyleProps(styles, options) {
  return function (Component) {
    return function (props) {
      var Comp = withStyles(function (theme) {
        return styles(_objectSpread({}, props, {
          theme: theme
        }));
      }, options)(Component);
      return React.createElement(Comp, props);
    };
  };
}
//# sourceMappingURL=withStyleProps.js.map